==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebCancelableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableEventArgsDetailDescriptionMetadata, _super);
    function WebCancelableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
            WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebCancelableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebCancelableEventArgsDetail", function () { return new WebCancelableEventArgsDetailDescription(); });
        a.z("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebCancelableEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebCancelableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescription } from "./WebCancelableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebCancelableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCancelableEventArgsDetailDescriptionMetadata, _super);
    function WebCancelableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCancelableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebCancelableEventArgsDetailDescriptionMetadata.a == null) {
            WebCancelableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCancelableEventArgsDetailDescriptionMetadata.c(WebCancelableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebCancelableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:CancelableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Cancel", "Boolean");
    };
    WebCancelableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebCancelableEventArgsDetail", function () { return new WebCancelableEventArgsDetailDescription(); });
        a.ab("WebCancelableEventArgsDetail", WebCancelableEventArgsDetailDescriptionMetadata.a);
    };
    WebCancelableEventArgsDetailDescriptionMetadata.$t = markType(WebCancelableEventArgsDetailDescriptionMetadata, 'WebCancelableEventArgsDetailDescriptionMetadata');
    WebCancelableEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebCancelableEventArgsDetailDescriptionMetadata };
